const body = document.querySelector("body");
const meinVideo = document.querySelector("#meinVideo");

// ================= die Buttons unterhalb des Videos =================

const videoPlay = document.querySelector("#videoPlay");
const videoLoop = document.querySelector("#videoLoop");
const videoSpeed = document.querySelector("#videoSpeed");
const videoSound = document.querySelector("#videoSound");

// ================= Anzeige, wie weit der Film schon abgespielt ist =================

// roter Kreis, der sich waagrecht bewegt, wenn Video läuft
// ACHTUNG: Wird auch weiter unten als "draggable Element" genutzt!
const anzeiger = document.querySelector("#anzeiger");

// die Anzeige von Dauer und Abspielzeit im Header
const abgespieltSpan = document.querySelector("#abgespielt");
const filmdauerSpan = document.querySelector("#filmdauer");

// Abfrage, ob die MouseTaste gedrück ist
// dann soll "anzeiger" (roter Kreis) nicht die aktuelle Filmposition anzeigen
// weil er sich sonst nicht "draggen" lässt
// wird hier noch nicht gebraucht!
let mouseGedrueckt = false;

// "#anzeiger" (roter kreis) zeigt an, wie weit der Film schon gelaufen ist
function videoAbspielPosition() {
  const filmDauer = meinVideo.duration;
  let abgespielt = meinVideo.currentTime;

  // "Math.round" rundet auf ganze Sekunden
  abgespieltSpan.textContent = Math.round(abgespielt);
  filmdauerSpan.textContent = Math.round(filmDauer);

  // hier berechnen, wie weit der rote Kreis wandern soll
  // je nachdem wie weit das Video vorangeschritten ist
  // Umrechnung in Prozent, die dann in CSS verwendet werden können
  // siehe "anzeiger.style.left = `${abgespieltProzent}%`;"
  let abgespieltProzent = (abgespielt * 100) / filmDauer;
  // console.log(filmDauer, abgespielt, abgespieltProzent);

  if (mouseGedrueckt === false) {
    anzeiger.style.left = `${abgespieltProzent}%`;
  }
}

// =============== VideoPlay-Button entsprechend anzeigen ===============

// die Zusatzinfos an bestimmten Stellen des Videos ein-/ausblenden
// "anfang" und "ende" sind die Sekunden des Videos,
// zwischen denen die Zusatzinfos sichtbar sein sollen
function zusatzInfosSichtbar(welches, anfang, ende) {
  if (meinVideo.currentTime > anfang && meinVideo.currentTime < ende) {
    welches.classList.add("angezeigt");
  } else {
    welches.classList.remove("angezeigt");
  }
}

// diese Funktion wird schon für die Steuerelemente verwendet und hier erweitert!
function videoZeitAbfragen() {
  // läuft das Video gerade?
  if (meinVideo.paused) {
    videoPlay.innerHTML = "▶";
    videoPlay.classList.remove("aktiv");
  } else {
    videoPlay.innerHTML = "❚❚";
    videoPlay.classList.add("aktiv");
  }

  // Zusatzinfos einblenden, wenn Video an entsprechender Stelle
  const morgenstimmung = document.querySelector("#morgenstimmung");
  zusatzInfosSichtbar(morgenstimmung, 27, 31);

  const traktor = document.querySelector("#traktor");
  zusatzInfosSichtbar(traktor, 301, 310);

  const prozession = document.querySelector("#prozession");
  zusatzInfosSichtbar(prozession, 367, 371);

  // "#anzeiger" (roter kreis) zeigt an, wie weit der Film schon gelaufen ist
  videoAbspielPosition();
}

// frägt laufend (alle 100ms) Abspielzeit ab und stellt den Button entsprechend dar
setInterval(videoZeitAbfragen, 100);

// ========================= videoSound an/aus =========================

function videoSoundAnAus() {
  if (meinVideo.muted) {
    meinVideo.muted = false;
    videoSound.classList.add("aktiv");
  } else {
    meinVideo.muted = true;
    videoSound.classList.remove("aktiv");
  }
}

// Clickt man auf den Button "videoSound", wird Sound "getoggelt"
videoSound.addEventListener("click", videoSoundAnAus);

// ========================= videoLooping =========================

// stellt ein, ob das Video als Loop oder nur einmal abläuft
function videoLooping() {
  if (meinVideo.loop == true) {
    meinVideo.loop = false;
    videoLoop.classList.remove("aktiv");
  } else {
    meinVideo.loop = true;
    videoLoop.classList.add("aktiv");
  }
}

// Clickt man auf den Button "videoLoop", wird "getoggelt",
// ob der Film  nur einmal oder als Endlosschleife abgespielt wird
videoLoop.addEventListener("click", videoLooping);

// ======================== videoStarten ========================

function videoStarten() {
  if (meinVideo.paused) {
    meinVideo.play();
  } else {
    meinVideo.pause();
  }
}

// Clickt man auf den Button "videoPlay", wird der Film abgespielt oder angehalten
videoPlay.addEventListener("click", videoStarten);

// clickt man auf das Video, wird dieses gestartet oder angehalten
meinVideo.addEventListener("click", videoStarten);

// ================== Liste mit verschiedenen Video-Startpunkten ==================

// alle Buttons in der Section "#startpunkte"
const startPunkte = document.querySelectorAll("#startpunkte button");

function videoStartpunktFestlegen(ereignis) {
  // fragt im HTML-Dokument den Wert von "data-startpunkt" ab
  let startpunkt = ereignis.target.dataset.startpunkt;

  // fragt im HTML-Dokument den Text (z.B. "Morgenstimmung") ab
  let beschreibung = ereignis.target.textContent;

  // verschiebt den Startpunkt des Videos auf die gewünschte Stelle
  meinVideo.currentTime = startpunkt;

  // ======= ab hier "Kosmetik" der Kapitelliste… =======
  // bisher schon angeklickter Kapitelname wieder normal darstellen
  const currentButton = document.querySelector("#startpunkte button.current");
  if (currentButton != null) {
    currentButton.classList.remove("current");
  }

  // aktuell angeklickter Kapitelname wird fett dargestellt
  ereignis.target.classList.add("current");
}

// Klickt man auf einen der Buttons bei "#startpunkte",
// wird die Funktion "videoStartpunktFestlegen" aufgerufen
startPunkte.forEach(function (ereignis) {
  ereignis.addEventListener("click", videoStartpunktFestlegen);
});
